( cd usr/lib/teTeX/bin ; rm -rf alldc )
( cd usr/lib/teTeX/bin ; ln -sf allcm alldc )
( cd usr/lib/teTeX/bin ; rm -rf amstex )
( cd usr/lib/teTeX/bin ; ln -sf virtex amstex )
( cd usr/lib/teTeX/bin ; rm -rf kpsepath )
( cd usr/lib/teTeX/bin ; ln -sf kpsetool kpsepath )
( cd usr/lib/teTeX/bin ; rm -rf kpsewhich )
( cd usr/lib/teTeX/bin ; ln -sf kpsetool kpsewhich )
( cd usr/lib/teTeX/bin ; rm -rf kpsexpand )
( cd usr/lib/teTeX/bin ; ln -sf kpsetool kpsexpand )
( cd usr/lib/teTeX/bin ; rm -rf latex )
( cd usr/lib/teTeX/bin ; ln -sf virtex latex )
( cd usr/lib/teTeX/bin ; rm -rf mf )
( cd usr/lib/teTeX/bin ; ln -sf virmf mf )
( cd usr/lib/teTeX/bin ; rm -rf mp )
( cd usr/lib/teTeX/bin ; ln -sf virmp mp )
